@@ -49,6 +49,7 @@ class Cover(Device):
         invert_position=False,
         invert_angle=False,
         device_updated_cb=None,
+        device_class=None,
     ):
         """Initialize Cover class."""
         # pylint: disable=too-many-arguments
@@ -110,6 +111,8 @@ class Cover(Device):
 
         self.travelcalculator = TravelCalculator(travel_time_down, travel_time_up)
 
+        self.device_class = device_class
+
     def _iter_remote_values(self):
         """Iterate the devices RemoteValue classes."""
         yield from (self.updown, self.step, self.stop_, self.position, self.angle)
@@ -128,6 +131,7 @@ class Cover(Device):
         travel_time_up = config.get("travel_time_up", cls.DEFAULT_TRAVEL_TIME_UP)
         invert_position = config.get("invert_position", False)
         invert_angle = config.get("invert_angle", False)
+        device_class = config.get("device_class")
 
         return cls(
             xknx,
@@ -143,6 +147,7 @@ class Cover(Device):
             travel_time_up=travel_time_up,
             invert_position=invert_position,
             invert_angle=invert_angle,
+            device_class=device_class,
         )
 
     def __str__(self):
