@@ -3,6 +3,8 @@ Module for managing setpoint shifting.
 
 DPT 6.010.
 """
+from typing import List
+
 from xknx.remote_value import RemoteValue1Count
 
 
@@ -17,6 +19,7 @@ class RemoteValueSetpointShift(RemoteValue1Count):
         device_name=None,
         after_update_cb=None,
         setpoint_shift_step=0.1,
+        passive_group_addresses: List[str] = None,
     ):
         """Initialize RemoteValueSetpointShift class."""
         # pylint: disable=too-many-arguments
@@ -27,6 +30,7 @@ class RemoteValueSetpointShift(RemoteValue1Count):
             device_name=device_name,
             feature_name="Setpoint shift value",
             after_update_cb=after_update_cb,
+            passive_group_addresses=passive_group_addresses,
         )
 
         self.setpoint_shift_step = setpoint_shift_step
